summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmdetailobjectedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmdetailobjectedit.h')
-rw-r--r--kpovmodeler/pmdetailobjectedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmdetailobjectedit.h b/kpovmodeler/pmdetailobjectedit.h
index 74aa3a29..e6224d59 100644
--- a/kpovmodeler/pmdetailobjectedit.h
+++ b/kpovmodeler/pmdetailobjectedit.h
@@ -35,12 +35,13 @@ class TQComboBox;
class PMDetailObjectEdit : public PMNamedObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMNamedObjectEdit Base;
public:
/**
* Creates a PMNamedObjectEdit with parent and name
*/
- PMDetailObjectEdit( TQWidget* parent, const char* name = 0 );
+ PMDetailObjectEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -35,12 +35,13 @@ class TQComboBox;
public:
/**
- * Creates a PMNamedObjectEdit with parent and name
+ * Creates a PMNamedObjectEdit with tqparent and name
*/